
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineRelocateDiskMoveOptions = Enum(
    'createNewChildDiskBacking',
    'moveAllDiskBackingsAndAllowSharing',
    'moveAllDiskBackingsAndDisallowSharing',
    'moveChildMostDiskBacking',

)
