
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostPatchManagerIntegrityStatus = Enum(
    'digestMismatch',
    'keyExpired',
    'keyNotFound',
    'keyRevoked',
    'notEnoughSignatures',
    'validated',
    'validationError',

)
