
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PerfStatsType = Enum(
    'absolute',
    'delta',
    'rate',

)
