
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDeviceFileExtension = Enum(
    'dsk',
    'flp',
    'iso',
    'rdm',
    'vmdk',

)
