
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskMode = Enum(
    'append',
    'independent_nonpersistent',
    'independent_persistent',
    'nonpersistent',
    'persistent',
    'undoable',

)
