
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

TaskFilterSpecTimeOption = Enum(
    'completedTime',
    'queuedTime',
    'startedTime',

)
