
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ComputeResourceHostSPBMLicenseInfoHostSPBMLicenseState = Enum(
    'licensed',
    'unknown',
    'unlicensed',

)
