
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFlagInfoVirtualExecUsage = Enum(
    'hvAuto',
    'hvOff',
    'hvOn',

)
