
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PerformanceManagerUnit = Enum(
    'joule',
    'kiloBytes',
    'kiloBytesPerSecond',
    'megaBytes',
    'megaBytesPerSecond',
    'megaHertz',
    'microsecond',
    'millisecond',
    'number',
    'percent',
    'second',
    'watt',

)
