
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

CustomizationSysprepRebootOption = Enum(
    'noreboot',
    'reboot',
    'shutdown',

)
