
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

CannotPowerOffVmInClusterOperation = Enum(
    'guestShutdown',
    'guestSuspend',
    'powerOff',
    'suspend',

)
