
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFlagInfoMonitorType = Enum(
    'debug',
    'release',
    'stats',

)
