
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskAdapterType = Enum(
    'busLogic',
    'ide',
    'lsiLogic',

)
