
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VAppAutoStartAction = Enum(
    'guestShutdown',
    'none',
    'powerOff',
    'powerOn',
    'suspend',

)
