
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ReplicationDiskConfigFaultReasonForFault = Enum(
    'diskNotFound',
    'diskTypeNotSupported',
    'duplicateDiskReplicationId',
    'invalidDiskKey',
    'invalidDiskReplicationId',
    'invalidPersistentFilePath',
    'reconfigureDiskReplicationIdNotAllowed',

)
