
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LinkDiscoveryProtocolConfigOperationType = Enum(
    'advertise',
    'both',
    'listen',
    'none',

)
