
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineTicketType = Enum(
    'device',
    'guestControl',
    'mks',

)
