
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualEthernetCardLegacyNetworkDeviceName = Enum(
    'bridged',
    'hostonly',
    'nat',

)
