
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostCapabilityVmDirectPathGen2UnsupportedReason = Enum(
    'hostNptDisabled',
    'hostNptIncompatibleHardware',
    'hostNptIncompatibleProduct',

)
