
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasConfigInfoHBDatastoreCandidate = Enum(
    'allFeasibleDs',
    'allFeasibleDsWithUserPreference',
    'userSelectedDs',

)
