
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DrsRecommendationReasonCode = Enum(
    'antiAffin',
    'fairnessCpuAvg',
    'fairnessMemAvg',
    'hostMaint',
    'jointAffin',

)
