
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostFirewallRulePortType = Enum(
    'dst',
    'src',

)
