
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConfigInfoNpivWwnType = Enum(
    'external',
    'host',
    'vc',

)
