
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostNumericSensorHealthState = Enum(
    'green',
    'red',
    'unknown',
    'yellow',

)
