
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NotSupportedDeviceForFTDeviceType = Enum(
    'paraVirtualSCSIController',
    'virtualVmxnet3',

)
