
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LicenseAssignmentFailedReason = Enum(
    'downgradeDisallowed',
    'hostsUnmanageableByVirtualCenterWithoutLicenseServer',
    'inventoryNotManageableByVirtualCenter',
    'keyEntityMismatch',

)
