
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticManagerLogFormat = Enum(
    'plain',

)
