
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostSystemConnectionState = Enum(
    'connected',
    'disconnected',
    'notResponding',

)
