
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DasConfigFaultDasConfigFaultReason = Enum(
    'HostMisconfiguration',
    'HostNetworkMisconfiguration',
    'InsufficientPrivileges',
    'NoPrimaryAgentAvailable',
    'Other',

)
