
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDisconnectedEventReasonCode = Enum(
    'agentOutOfDate',
    'agentUpgrade',
    'insufficientLicenses',
    'licenseExpired',
    'passwordDecryptFailure',
    'sslThumbprintVerifyFailed',
    'unknown',
    'userRequest',

)
