
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmFaultToleranceInvalidFileBackingDeviceType = Enum(
    'virtualCdrom',
    'virtualDisk',
    'virtualFloppy',
    'virtualParallelPort',
    'virtualSerialPort',

)
