
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFlagInfoVirtualMmuUsage = Enum(
    'automatic',
    'off',
    'on',

)
