
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDeviceURIBackingOptionDirection = Enum(
    'client',
    'server',

)
