
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LicenseManagerLicenseKey = Enum(
    'backup',
    'das',
    'drs',
    'drsPower',
    'esxExpress',
    'esxFull',
    'esxHost',
    'esxVmtn',
    'gsxHost',
    'iscsi',
    'nas',
    'san',
    'serverHost',
    'vc',
    'vcExpress',
    'vmotion',
    'vsmp',

)
