
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DasVmPriority = Enum(
    'disabled',
    'high',
    'low',
    'medium',

)
