
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LicenseFeatureInfoSourceRestriction = Enum(
    'file',
    'served',
    'unrestricted',

)
