
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

EntityReferenceEntityType = Enum(
    'cluster',
    'datacenter',
    'datastore',
    'host',
    'nasMount',
    'resourcePool',
    'scsiAdapter',
    'scsiPath',
    'scsiTarget',
    'scsiVolume',
    'storagePod',
    'vm',
    'vmFile',

)
