
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

StateAlarmOperator = Enum(
    'isEqual',
    'isUnequal',

)
