
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

GuestFileType = Enum(
    'directory',
    'file',
    'symlink',

)
