
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DVPortStatusVmDirectPathGen2InactiveReasonNetwork = Enum(
    'portNptDisabledForPort',
    'portNptIncompatibleDvs',
    'portNptNoCompatibleNics',
    'portNptNoVirtualFunctionsAvailable',

)
