
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ReplicationVmFaultReasonForFault = Enum(
    'invalidInstanceId',
    'invalidState',
    'notConfigured',
    'offlineReplicating',
    'poweredOff',
    'poweredOn',
    'suspended',

)
