
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostCpuPowerManagementInfoPolicyType = Enum(
    'dynamicPolicy',
    'off',
    'staticPolicy',

)
