
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NetIpConfigInfoIpAddressOrigin = Enum(
    'dhcp',
    'linklayer',
    'manual',
    'other',
    'random',

)
