
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDasErrorEventHostDasErrorReason = Enum(
    'agentFailed',
    'agentShutdown',
    'communicationInitFailed',
    'configFailed',
    'healthCheckScriptFailed',
    'isolationAddressUnpingable',
    'other',
    'timeout',

)
