
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineStandbyActionType = Enum(
    'checkpoint',
    'powerOnSuspend',

)
