
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NetIpConfigInfoIpAddressStatus = Enum(
    'deprecated',
    'duplicate',
    'inaccessible',
    'invalid',
    'preferred',
    'tentative',
    'unknown',

)
