
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

CannotMoveFaultToleranceVmMoveType = Enum(
    'cluster',
    'resourcePool',

)
