
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDiskPartitionInfoType = Enum(
    'extended',
    'linuxNative',
    'linuxSwap',
    'none',
    'ntfs',
    'vmfs',
    'vmkDiagnostic',

)
