
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostReplayUnsupportedReason = Enum(
    'cpuidLimitSet',
    'hvDisabled',
    'incompatibleCpu',
    'incompatibleProduct',
    'oldBIOS',
    'unknown',

)
