
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VasaProviderProfile = Enum(
    'blockDevice',
    'capability',
    'fileSystem',

)
