
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DisallowedChangeByServiceDisallowedChange = Enum(
    'hotExtendDisk',

)
