
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

IscsiPortInfoPathStatus = Enum(
    'active',
    'lastActive',
    'notUsed',
    'standBy',

)
