
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ProfileNumericComparator = Enum(
    'equal',
    'greaterThan',
    'greaterThanEqual',
    'lessThan',
    'lessThanEqual',
    'notEqual',

)
