
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PhysicalNicResourcePoolSchedulerDisallowedReason = Enum(
    'hardwareUnsupported',
    'userOptOut',

)
