
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineUsbInfoSpeed = Enum(
    'full',
    'high',
    'low',
    'superSpeed',
    'unknownSpeed',

)
