
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineMemoryAllocationPolicy = Enum(
    'swapMost',
    'swapNone',
    'swapSome',

)
