
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PerfSummaryType = Enum(
    'average',
    'latest',
    'maximum',
    'minimum',
    'none',
    'summation',

)
