
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostSnmpAgentCapability = Enum(
    'COMPLETE',
    'CONFIGURATION',
    'DIAGNOSTICS',

)
