
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NetIpStackInfoPreference = Enum(
    'high',
    'low',
    'medium',
    'reserved',

)
