
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FileSystemInterface = Enum(
    'nfs',
    'otherFileSystem',

)
