
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VAppCloneSpecProvisioningType = Enum(
    'sameAsSource',
    'thick',
    'thin',

)
