
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterPowerOnVmOption = Enum(
    'OverrideAutomationLevel',
    'ReserveResources',

)
