
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachinePowerOffBehavior = Enum(
    'powerOff',
    'prompt',
    'revert',

)
