
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineHtSharing = Enum(
    'any',
    'internal',
    'none',

)
