
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDeviceConfigSpecFileOperation = Enum(
    'create',
    'destroy',
    'replace',

)
