
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ComplianceResultStatus = Enum(
    'compliant',
    'nonCompliant',
    'unknown',

)
