
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ScsiLunState = Enum(
    'degraded',
    'error',
    'lostCommunication',
    'off',
    'ok',
    'quiesced',
    'unknownState',

)
