
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostCpuPackageVendor = Enum(
    'amd',
    'intel',
    'unknown',

)
