
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

AutoStartAction = Enum(
    'guestShutdown',
    'none',
    'powerOff',
    'powerOn',
    'suspend',
    'systemDefault',

)
