
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ScsiLunType = Enum(
    'cdrom',
    'communications',
    'disk',
    'enclosure',
    'mediaChanger',
    'opticalDevice',
    'printer',
    'processor',
    'scanner',
    'storageArrayController',
    'tape',
    'unknown',
    'worm',

)
