
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ArrayUpdateOperation = Enum(
    'add',
    'edit',
    'remove',

)
