
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostFeatureVersionKey = Enum(
    'faultTolerance',

)
