
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualPortgroupMetaTagName = Enum(
    'dvsName',
    'portgroupName',
    'portIndex',

)
