
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ActionParameter = Enum(
    'alarm',
    'alarmName',
    'declaringSummary',
    'eventDescription',
    'newStatus',
    'oldStatus',
    'target',
    'targetName',
    'triggeringSummary',

)
