
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasConfigInfoVmMonitoringState = Enum(
    'vmAndAppMonitoring',
    'vmMonitoringDisabled',
    'vmMonitoringOnly',

)
