
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostSystemIdentificationInfoIdentifier = Enum(
    'AssetTag',
    'OemSpecificString',
    'ServiceTag',

)
