
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HttpNfcLeaseState = Enum(
    'done',
    'error',
    'initializing',
    'ready',

)
