
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

WillLoseHAProtectionResolution = Enum(
    'relocate',
    'svmotion',

)
