
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LicenseFeatureInfoUnit = Enum(
    'cpuCore',
    'cpuPackage',
    'host',
    'server',
    'vm',

)
