
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

GuestOsDescriptorSupportLevel = Enum(
    'experimental',
    'legacy',
    'supported',
    'terminated',

)
