
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmFailedStartingSecondaryEventFailureReason = Enum(
    'incompatibleHost',
    'loginFailed',
    'migrateFailed',
    'registerVmFailed',

)
