
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

OvfConsumerOstNodeType = Enum(
    'envelope',
    'virtualSystem',
    'virtualSystemCollection',

)
