
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VasaProviderStatus = Enum(
    'offline',
    'online',
    'syncError',
    'unknown',

)
