
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VMotionCompatibilityType = Enum(
    'cpu',
    'software',

)
