
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDeviceConnectInfoStatus = Enum(
    'ok',
    'recoverableError',
    'unrecoverableError',
    'untried',

)
