
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostMountMode = Enum(
    'readOnly',
    'readWrite',

)
