
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PhysicalNicVmDirectPathGen2SupportedMode = Enum(
    'upt',

)
