
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DeviceNotSupportedReason = Enum(
    'guest',
    'host',

)
