
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

StorageDrsPodConfigInfoBehavior = Enum(
    'automated',
    'manual',

)
