
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualPortgroupPortgroupType = Enum(
    'earlyBinding',
    'ephemeral',
    'lateBinding',

)
