
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDigestInfoDigestMethodType = Enum(
    'MD5',
    'SHA1',

)
