
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostVirtualNicManagerNicType = Enum(
    'faultToleranceLogging',
    'management',
    'vmotion',

)
