
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineAppHeartbeatStatusType = Enum(
    'appStatusGray',
    'appStatusGreen',
    'appStatusRed',

)
