
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualSCSISharing = Enum(
    'noSharing',
    'physicalSharing',
    'virtualSharing',

)
