
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

StoragePlacementSpecPlacementType = Enum(
    'clone',
    'create',
    'reconfigure',
    'relocate',

)
