
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDistributedVirtualSwitchManagerNetworkResourcePoolKey = Enum(
    'faultTolerance',
    'iSCSI',
    'management',
    'nfs',
    'virtualMachine',
    'vmotion',

)
