
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualPointingDeviceHostChoice = Enum(
    'autodetect',
    'intellimouseExplorer',
    'intellimousePs2',
    'logitechMouseman',
    'microsoft_serial',
    'mousemanSerial',
    'mouseSystems',
    'ps2',

)
