
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskCompatibilityMode = Enum(
    'physicalMode',
    'virtualMode',

)
