
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConnectionState = Enum(
    'connected',
    'disconnected',
    'inaccessible',
    'invalid',
    'orphaned',

)
