
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualSwitchNicTeamingPolicyMode = Enum(
    'failover_explicit',
    'loadbalance_ip',
    'loadbalance_loadbased',
    'loadbalance_srcid',
    'loadbalance_srcmac',

)
