
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NodeStatus = Enum(
    'degraded',
    'down',
    'notReported',
    'unknown',
    'up',

)
