
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostStandbyMode = Enum(
    'entering',
    'exiting',
    'in',
    'none',

)
