
from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.profile_manager import ProfileManager

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ClusterProfileManager(ProfileManager):
    ''''''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ClusterProfileManager):
        super(ClusterProfileManager, self).__init__(core, name=name, ref=ref, type=type)

    

    