
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFileLayoutExFileType = Enum(
    'config',
    'core',
    'digestDescriptor',
    'digestExtent',
    'diskDescriptor',
    'diskExtent',
    'diskReplicationState',
    'extendedConfig',
    'log',
    'nvram',
    'screenshot',
    'snapshotData',
    'snapshotList',
    'snapshotManifestList',
    'stat',
    'suspend',
    'swap',
    'uwswap',

)
