
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFaultToleranceState = Enum(
    'disabled',
    'enabled',
    'needSecondary',
    'notConfigured',
    'running',
    'starting',

)
