
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineToolsStatus = Enum(
    'toolsNotInstalled',
    'toolsNotRunning',
    'toolsOk',
    'toolsOld',

)
