
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PropertyChangeOp = Enum(
    'add',
    'assign',
    'indirectRemove',
    'remove',

)
