
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

AgentInstallFailedReason = Enum(
    'AgentNotReachable',
    'AgentNotRunning',
    'AgentUploadFailed',
    'AgentUploadTimedout',
    'InstallTimedout',
    'NotEnoughSpaceOnDevice',
    'PrepareToUpgradeFailed',
    'SignatureVerificationFailed',
    'UnknownInstallerError',

)
