
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineGuestOsFamily = Enum(
    'darwinGuestFamily',
    'linuxGuest',
    'netwareGuest',
    'otherGuestFamily',
    'solarisGuest',
    'windowsGuest',

)
