
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ValidateMigrationTestType = Enum(
    'compatibilityTests',
    'diskAccessibilityTests',
    'resourceTests',
    'sourceTests',

)
