
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

MetricAlarmOperator = Enum(
    'isAbove',
    'isBelow',

)
