
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConfigInfoSwapPlacementType = Enum(
    'hostLocal',
    'inherit',
    'vmDirectory',

)
