
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ThinProvisioningStatus = Enum(
    'GREEN',
    'RED',
    'YELLOW',

)
