
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConfigSpecNpivWwnOp = Enum(
    'extend',
    'generate',
    'remove',
    'set',

)
