
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostImageAcceptanceLevel = Enum(
    'community',
    'partner',
    'vmware_accepted',
    'vmware_certified',

)
