
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

OvfCreateImportSpecParamsDiskProvisioningType = Enum(
    'eagerZeroedThick',
    'flat',
    'monolithicFlat',
    'monolithicSparse',
    'sparse',
    'thick',
    'thin',
    'twoGbMaxExtentFlat',
    'twoGbMaxExtentSparse',

)
