
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DayOfWeek = Enum(
    'friday',
    'monday',
    'saturday',
    'sunday',
    'thursday',
    'tuesday',
    'wednesday',

)
