
from ..thirdparty import Enum

ManagedObjectTypes = Enum(
    "ReflectManagedMethodExecuter",
    "InternalDynamicTypeManager",
    "Alarm",
    "AlarmManager",
    "AuthorizationManager",
    "ClusterComputeResource",
    "ClusterProfile",
    "ClusterProfileManager",
    "ComputeResource",
    "ContainerView",
    "CustomFieldsManager",
    "CustomizationSpecManager",
    "Datacenter",
    "Datastore",
    "DiagnosticManager",
    "DistributedVirtualPortgroup",
    "DistributedVirtualSwitch",
    "DistributedVirtualSwitchManager",
    "EnvironmentBrowser",
    "EventHistoryCollector",
    "EventManager",
    "ExtensibleManagedObject",
    "ExtensionManager",
    "FileManager",
    "Folder",
    "GuestAuthManager",
    "GuestFileManager",
    "GuestOperationsManager",
    "GuestProcessManager",
    "HistoryCollector",
    "HostActiveDirectoryAuthentication",
    "HostAuthenticationManager",
    "HostAuthenticationStore",
    "HostAutoStartManager",
    "HostBootDeviceSystem",
    "HostCacheConfigurationManager",
    "HostCpuSchedulerSystem",
    "HostDatastoreBrowser",
    "HostDatastoreSystem",
    "HostDateTimeSystem",
    "HostDiagnosticSystem",
    "HostDirectoryStore",
    "HostEsxAgentHostManager",
    "HostFirewallSystem",
    "HostFirmwareSystem",
    "HostHealthStatusSystem",
    "HostImageConfigManager",
    "HostKernelModuleSystem",
    "HostLocalAccountManager",
    "HostLocalAuthentication",
    "HostMemorySystem",
    "HostNetworkSystem",
    "HostPatchManager",
    "HostPciPassthruSystem",
    "HostPowerSystem",
    "HostProfile",
    "HostProfileManager",
    "HostServiceSystem",
    "HostSnmpSystem",
    "HostStorageSystem",
    "HostSystem",
    "HostVMotionSystem",
    "HostVirtualNicManager",
    "HttpNfcLease",
    "InventoryView",
    "IpPoolManager",
    "IscsiManager",
    "LicenseAssignmentManager",
    "LicenseManager",
    "ListView",
    "LocalizationManager",
    "ManagedEntity",
    "ManagedObjectView",
    "Network",
    "OptionManager",
    "OvfManager",
    "PerformanceManager",
    "Profile",
    "ProfileComplianceManager",
    "ProfileManager",
    "PropertyCollector",
    "PropertyFilter",
    "ResourcePlanningManager",
    "ResourcePool",
    "ScheduledTask",
    "ScheduledTaskManager",
    "SearchIndex",
    "ServiceInstance",
    "SessionManager",
    "StoragePod",
    "StorageResourceManager",
    "Task",
    "TaskHistoryCollector",
    "TaskManager",
    "UserDirectory",
    "View",
    "ViewManager",
    "VirtualApp",
    "VirtualDiskManager",
    "VirtualMachine",
    "VirtualMachineCompatibilityChecker",
    "VirtualMachineProvisioningChecker",
    "VirtualMachineSnapshot",
    "VirtualizationManager",
    "VmwareDistributedVirtualSwitch",
    "SmsProvider",
    "SmsServiceInstance",
    "SmsStorageManager",
    "SmsTask",
    "VasaProvider"
)
