
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostCapabilityFtUnsupportedReason = Enum(
    'ftNotLicensed',
    'haAgentIssue',
    'missingFTLoggingNic',
    'missingVMotionNic',
    'vMotionNotLicensed',

)
