
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DVPortStatusVmDirectPathGen2InactiveReasonOther = Enum(
    'portNptIncompatibleConnectee',
    'portNptIncompatibleHost',

)
