
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FileSystemInterfaceVersion = Enum(
    'NFSV3_0',

)
