
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ThirdPartyLicenseAssignmentFailedReason = Enum(
    'licenseAssignmentFailed',
    'moduleNotInstalled',

)
