
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

SessionManagerHttpServiceRequestSpecMethod = Enum(
    'httpConnect',
    'httpDelete',
    'httpGet',
    'httpHead',
    'httpOptions',
    'httpPost',
    'httpPut',
    'httpTrace',

)
