
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostInternetScsiHbaChapAuthenticationType = Enum(
    'chapDiscouraged',
    'chapPreferred',
    'chapProhibited',
    'chapRequired',

)
