
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

SmsTaskState = Enum(
    'error',
    'running',
    'success',

)
