
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NumVirtualCpusIncompatibleReason = Enum(
    'faultTolerance',
    'recordReplay',

)
