
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

EventCategory = Enum(
    'error',
    'info',
    'user',
    'warning',

)
