
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticPartitionType = Enum(
    'multiHost',
    'singleHost',

)
