
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostConfigChangeMode = Enum(
    'modify',
    'replace',

)
