
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

GuestOsDescriptorFirmwareType = Enum(
    'bios',
    'efi',

)
