
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmwareDistributedVirtualSwitchPvlanPortType = Enum(
    'community',
    'isolated',
    'promiscuous',

)
