
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostSystemPowerState = Enum(
    'poweredOff',
    'poweredOn',
    'standBy',
    'unknown',

)
