
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmShutdownOnIsolationEventOperation = Enum(
    'poweredOff',
    'shutdown',

)
