
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualEthernetCardMacType = Enum(
    'assigned',
    'generated',
    'manual',

)
