
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostFirewallRuleProtocol = Enum(
    'tcp',
    'udp',

)
