
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FilterSpecComparisonOperator = Enum(
    'beginsWith',
    'contains',
    'endsWith',
    'equal',
    'greaterThanOrEqual',
    'lessThanOrEqual',
    'notContains',
    'notEqual',

)
