
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

EventAlarmExpressionComparisonOperator = Enum(
    'doesNotEndWith',
    'doesNotStartWith',
    'endsWith',
    'equals',
    'notEqualTo',
    'startsWith',

)
