
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DatastoreAccessible = Enum(
    'False',
    'True',

)
