
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachinePowerOpType = Enum(
    'hard',
    'preset',
    'soft',

)
