
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterProfileServiceType = Enum(
    'DPM',
    'DRS',
    'FT',
    'HA',

)
