
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostUnresolvedVmfsExtentUnresolvedReason = Enum(
    'diskIdMismatch',
    'uuidConflict',

)
