
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DatastoreSummaryMaintenanceModeState = Enum(
    'enteringMaintenance',
    'inMaintenance',
    'normal',

)
