
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VAppIPAssignmentInfoAllocationSchemes = Enum(
    'dhcp',
    'ovfenv',

)
