
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineMovePriority = Enum(
    'defaultPriority',
    'highPriority',
    'lowPriority',

)
