
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

MultipathState = Enum(
    'active',
    'dead',
    'disabled',
    'standby',
    'unknown',

)
