
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineUsbInfoFamily = Enum(
    'audio',
    'bluetooth',
    'communication',
    'hid',
    'hid_bootable',
    'hub',
    'imaging',
    'other',
    'pda',
    'physical',
    'printer',
    'security',
    'smart_card',
    'storage',
    'unknownFamily',
    'vendor_specific',
    'video',
    'wireless',
    'wusb',

)
