
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostInternetScsiHbaDigestType = Enum(
    'digestDiscouraged',
    'digestPreferred',
    'digestProhibited',
    'digestRequired',

)
