
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

UpgradePolicy = Enum(
    'manual',
    'upgradeAtPowerCycle',

)
