
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FtIssuesOnHostHostSelectionType = Enum(
    'drs',
    'user',
    'vc',

)
