
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineDeviceRuntimeInfoVirtualEthernetCardRuntimeStateVmDirectPathGen2InactiveReasonVm = Enum(
    'vmNptConflictingIOChainConfigured',
    'vmNptConflictingOperationInProgress',
    'vmNptDisabledOrDisconnectedAdapter',
    'vmNptFaultToleranceOrRecordReplayConfigured',
    'vmNptIncompatibleAdapterFeatures',
    'vmNptIncompatibleAdapterType',
    'vmNptIncompatibleBackingType',
    'vmNptIncompatibleGuest',
    'vmNptIncompatibleGuestDriver',
    'vmNptInsufficientMemoryReservation',
    'vmNptMonitorBlocks',
    'vmNptOutOfIntrVector',
    'vmNptRuntimeError',

)
