
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

BlockDeviceInterface = Enum(
    'fc',
    'fcoe',
    'iscsi',
    'otherBlock',

)
