
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineToolsRunningStatus = Enum(
    'guestToolsExecutingScripts',
    'guestToolsNotRunning',
    'guestToolsRunning',

)
