
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ReplicationVmConfigFaultReasonForFault = Enum(
    'cannotRetrieveVmReplicationConfiguration',
    'incompatibleHwVersion',
    'invalidDestinationIpAddress',
    'invalidDestinationPort',
    'invalidExtraVmOptions',
    'invalidGenerationNumber',
    'invalidPriorConfiguration',
    'invalidVmReplicationId',
    'outOfBoundsRpoValue',
    'reconfigureVmReplicationIdNotAllowed',
    'replicationAlreadyEnabled',
    'replicationConfigurationFailed',
    'replicationNotEnabled',
    'staleGenerationNumber',

)
