
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineToolsVersionStatus = Enum(
    'guestToolsBlacklisted',
    'guestToolsCurrent',
    'guestToolsNeedUpgrade',
    'guestToolsNotInstalled',
    'guestToolsSupportedNew',
    'guestToolsSupportedOld',
    'guestToolsTooNew',
    'guestToolsTooOld',
    'guestToolsUnmanaged',

)
