
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ReplicationVmState = Enum(
    'active',
    'error',
    'idle',
    'none',
    'paused',
    'syncing',

)
