
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostVmciAccessManagerMode = Enum(
    'grant',
    'replace',
    'revoke',

)
