
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineScsiPassthroughType = Enum(
    'cdrom',
    'com',
    'disk',
    'media',
    'optical',
    'printer',
    'processor',
    'raid',
    'scanner',
    'tape',
    'unknown',
    'worm',

)
