
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

WeekOfMonth = Enum(
    'first',
    'fourth',
    'last',
    'second',
    'third',

)
