
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ActionType = Enum(
    'HostMaintenanceV1',
    'HostPowerV1',
    'MigrationV1',
    'StorageMigrationV1',
    'StoragePlacementV1',
    'VmPowerV1',

)
