
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostIncompatibleForRecordReplayReason = Enum(
    'processor',
    'product',

)
