
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

EventFilterSpecRecursionOption = Enum(
    'all',
    'children',
    'self',

)
