
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostHardwareElementStatus = Enum(
    'Green',
    'Red',
    'Unknown',
    'Yellow',

)
