
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualSwitchPortConnecteeConnecteeType = Enum(
    'hostConsoleVnic',
    'hostVmkVnic',
    'pnic',
    'vmVnic',

)
