
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineRelocateTransformation = Enum(
    'flat',
    'sparse',

)
