
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmDasBeingResetEventReasonCode = Enum(
    'appHeartbeatFailure',
    'vmtoolsHeartbeatFailure',

)
