
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostPatchManagerInstallState = Enum(
    'hostRestarted',
    'imageActive',

)
