
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostNumericSensorType = Enum(
    'fan',
    'other',
    'power',
    'temperature',
    'voltage',

)
