
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskType = Enum(
    'eagerZeroedThick',
    'flatMonolithic',
    'preallocated',
    'raw',
    'rdm',
    'rdmp',
    'sparse2Gb',
    'sparseMonolithic',
    'thick',
    'thick2Gb',
    'thin',

)
