
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FileSystemMountInfoVStorageSupportStatus = Enum(
    'vStorageSupported',
    'vStorageUnknown',
    'vStorageUnsupported',

)
