
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

AutoStartWaitHeartbeatSetting = Enum(
    'no',
    'systemDefault',
    'yes',

)
