
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticPartitionStorageType = Enum(
    'directAttached',
    'networkAttached',

)
