
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineRecordReplayState = Enum(
    'inactive',
    'recording',
    'replaying',

)
