
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasVmSettingsIsolationResponse = Enum(
    'clusterIsolationResponse',
    'none',
    'powerOff',
    'shutdown',

)
