
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LinkDiscoveryProtocolConfigProtocolType = Enum(
    'cdp',
    'lldp',

)
