
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FibreChannelPortType = Enum(
    'fabric',
    'loop',
    'pointToPoint',
    'unknown',

)
