
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostProfileManagerAnswerFileStatus = Enum(
    'invalid',
    'unknown',
    'valid',

)
