
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticManagerLogCreator = Enum(
    'hostd',
    'install',
    'recordLog',
    'serverd',
    'vpxa',
    'vpxClient',
    'vpxd',

)
