
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FilterSpecLogicalOperator = Enum(
    'logicalAnd',
    'logicalOr',

)
