
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostFirewallRuleDirection = Enum(
    'inbound',
    'outbound',

)
