
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DrsBehavior = Enum(
    'fullyAutomated',
    'manual',
    'partiallyAutomated',

)
