
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasConfigInfoServiceState = Enum(
    'disabled',
    'enabled',

)
