
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostInternetScsiHbaNetworkBindingSupportType = Enum(
    'notsupported',
    'optional',
    'required',

)
