
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskDeltaDiskFormat = Enum(
    'nativeFormat',
    'redoLogFormat',

)
