
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostPowerOperationType = Enum(
    'powerOff',
    'powerOn',

)
