
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NetBIOSConfigInfoMode = Enum(
    'disabled',
    'enabled',
    'enabledViaDHCP',
    'unknown',

)
