
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

InternetScsiSnsDiscoveryMethod = Enum(
    'isnsDhcp',
    'isnsSlp',
    'isnsStatic',

)
