
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineGuestState = Enum(
    'notRunning',
    'resetting',
    'running',
    'shuttingDown',
    'standby',
    'unknown',

)
