
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostUnresolvedVmfsResolutionSpecVmfsUuidResolution = Enum(
    'forceMount',
    'resignature',

)
