
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmFaultToleranceConfigIssueReasonForIssue = Enum(
    'esxAgentVm',
    'ftSecondaryVm',
    'ftUnsupportedHardware',
    'ftUnsupportedProduct',
    'haNotEnabled',
    'hasLocalDisk',
    'hasSnapshots',
    'hostInactive',
    'missingFTLoggingNic',
    'missingVMotionNic',
    'moreThanOneSecondary',
    'multipleVCPU',
    'noConfig',
    'recordReplayNotSupported',
    'replayNotSupported',
    'templateVm',
    'thinDisk',
    'verifySSLCertificateFlagNotSet',
    'video3dEnabled',

)
