
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualSwitchProductSpecOperationType = Enum(
    'notifyAvailableUpgrade',
    'preInstall',
    'proceedWithUpgrade',
    'updateBundleInfo',
    'upgrade',

)
