
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LicenseManagerState = Enum(
    'fault',
    'initializing',
    'marginal',
    'normal',

)
