
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

LicenseReservationInfoState = Enum(
    'licensed',
    'noLicense',
    'notUsed',
    'unlicensedUse',

)
