
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

CheckTestType = Enum(
    'datastoreTests',
    'hostTests',
    'resourcePoolTests',
    'sourceTests',

)
