
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualAppVAppState = Enum(
    'started',
    'starting',
    'stopped',
    'stopping',

)
