
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasAamNodeStateDasState = Enum(
    'agentShutdown',
    'configuring',
    'error',
    'initialized',
    'nodeFailed',
    'running',
    'unconfiguring',
    'uninitialized',

)
