
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

CustomizationNetBIOSMode = Enum(
    'disableNetBIOS',
    'enableNetBIOS',
    'enableNetBIOSViaDhcp',

)
