
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VAppIPAssignmentInfoIpAllocationPolicy = Enum(
    'dhcpPolicy',
    'fixedPolicy',
    'transientPolicy',

)
