
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PortGroupConnecteeType = Enum(
    'host',
    'systemManagement',
    'unknown',
    'virtualMachine',

)
