
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostPatchManagerReason = Enum(
    'conflictLib',
    'conflictPatch',
    'hasDependentPatch',
    'missingLib',
    'missingPatch',
    'obsoleted',

)
