
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ClusterDasFdmAvailabilityState = Enum(
    'connectedToMaster',
    'election',
    'fdmUnreachable',
    'hostDown',
    'initializationError',
    'master',
    'networkIsolated',
    'networkPartitionedFromMaster',
    'uninitializationError',
    'uninitialized',

)
