
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDiskPartitionInfoPartitionFormat = Enum(
    'gpt',
    'mbr',
    'unknown',

)
