
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

RecommendationReasonCode = Enum(
    'antiAffin',
    'balanceDatastoreIOLoad',
    'balanceDatastoreSpaceUsage',
    'checkResource',
    'datastoreMaint',
    'datastoreSpaceOutage',
    'enterStandby',
    'fairnessCpuAvg',
    'fairnessMemAvg',
    'hostMaint',
    'increaseCapacity',
    'iolbDisabledInternal',
    'jointAffin',
    'powerOnVm',
    'powerSaving',
    'reservationCpu',
    'reservationMem',
    'storagePlacement',
    'unreservedCapacity',
    'virtualDiskAntiAffin',
    'virtualDiskJointAffin',
    'vmHostHardAffinity',
    'vmHostSoftAffinity',

)
