
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostLowLevelProvisioningManagerReloadTarget = Enum(
    'currentConfig',
    'snapshotConfig',

)
