
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NetIpStackInfoEntryType = Enum(
    'dynamic',
    'invalid',
    'manual',
    'other',

)
