
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ObjectUpdateKind = Enum(
    'enter',
    'leave',
    'modify',

)
