
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

CustomizationLicenseDataMode = Enum(
    'perSeat',
    'perServer',

)
