
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineTargetInfoConfigurationTag = Enum(
    'clusterWide',
    'compliant',

)
