
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VAppIPAssignmentInfoProtocols = Enum(
    'IPv4',
    'IPv6',

)
