
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostActiveDirectoryInfoDomainMembershipStatus = Enum(
    'clientTrustBroken',
    'inconsistentTrust',
    'noServers',
    'ok',
    'otherProblem',
    'serverTrustBroken',
    'unknown',

)
