
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostLicensableResourceKey = Enum(
    'memoryForVms',
    'memorySize',
    'numCpuCores',
    'numCpuPackages',
    'numVmsStarted',
    'numVmsStarting',

)
