
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineNeedSecondaryReason = Enum(
    'divergence',
    'initializing',
    'lostConnection',
    'other',
    'partialHardwareFailure',
    'userAction',

)
