
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ScsiLunDescriptorQuality = Enum(
    'highQuality',
    'lowQuality',
    'mediumQuality',
    'unknownQuality',

)
