
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

InvalidProfileReferenceHostReason = Enum(
    'incompatibleVersion',
    'missingReferenceHost',

)
