
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualSwitchHostMemberHostComponentState = Enum(
    'disconnected',
    'down',
    'outOfSync',
    'pending',
    'up',
    'warning',

)
