
########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

SlpDiscoveryMethod = Enum(
    'slpAutoMulticast',
    'slpAutoUnicast',
    'slpDhcp',
    'slpManual',

)
